# -*- coding: utf-8 -*-

from __future__ import absolute_import, division, print_function

import pytest

import datetime
import os

from pywaterinfo.waterinfo import Waterinfo

# use a session for VMM that can be used among tests
vmm_client = (
    "MzJkY2VlY2UtODI2Yy00Yjk4LTljMmQtYjE2OTc4ZjBjYTZhOj"
    "RhZGE4NzFhLTk1MjgtNGI0ZC1iZmQ1LWI1NzBjZThmNGQyZA=="
)

hic_client = os.environ.get("HIC_TOKEN")


@pytest.fixture
def patch_retention(monkeypatch):
    retention = datetime.timedelta(seconds=1)
    monkeypatch.setattr("pywaterinfo.waterinfo.CACHE_RETENTION", retention)


@pytest.fixture(scope="module")
def vmm_connection():
    return Waterinfo("vmm", token=vmm_client)


@pytest.fixture(scope="module")
def hic_connection():
    if hic_client:
        return Waterinfo("hic", token=hic_client)
    else:
        return Waterinfo("hic")


@pytest.fixture(scope="module")
def df_timeseries(vmm_connection):
    return vmm_connection.get_timeseries_values(
        78124042, start="20190501", end="20190502"
    )



import time

from pywaterinfo import Waterinfo


def test_cache_vmm(vmm_connection):
    """Second call of the same request is retrieved from cache for VMM requests."""
    vmm_connection.clear_cache()
    data, res = vmm_connection.request_kiwis({"request": "getRequestInfo"})
    assert not res.from_cache
    data, res = vmm_connection.request_kiwis({"request": "getRequestInfo"})
    assert res.from_cache


def test_cache_hic(hic_connection):
    """Second call of the same request is retrieved from cache for HIC requests."""
    hic_connection.clear_cache()
    data, res = hic_connection.request_kiwis({"request": "getRequestInfo"})
    assert not res.from_cache
    data, res = hic_connection.request_kiwis({"request": "getRequestInfo"})
    assert res.from_cache


def test_clear_cache(vmm_connection):
    """Cache is cleared."""
    vmm_connection.clear_cache()
    data, res = vmm_connection.request_kiwis({"request": "getRequestInfo"})
    assert not res.from_cache
    vmm_connection.clear_cache()
    data, res = vmm_connection.request_kiwis({"request": "getRequestInfo"})
    assert not res.from_cache


def test_cache_retention(patch_retention):
    """Request is not from cache after expiration date.

    Uses monkeypatch version of the CACHE_RETENTION timing for unit testing.
    """
    vmm = Waterinfo("vmm")
    data, res = vmm.request_kiwis({"request": "getRequestInfo"})

    time.sleep(2)
    data, res = vmm.request_kiwis({"request": "getRequestInfo"})
    assert not res.from_cache



# -*- coding: utf-8 -*-
"""
The :class:`pywaterinfo.Waterinfo` is the main
class for waterinfo.be data query interactions.
"""

from pkg_resources import DistributionNotFound, get_distribution

from .waterinfo import HIC_BASE, VMM_BASE, Waterinfo

try:
    # Change here if project is renamed and does not equal the package name
    dist_name = __name__
    __version__ = get_distribution(dist_name).version
except DistributionNotFound:
    __version__ = "unknown"
finally:
    del get_distribution, DistributionNotFound


__all__ = ["HIC_BASE", "VMM_BASE", "Waterinfo"]



# -*- coding: utf-8 -*-
"""
    Setup file for pywaterinfo.
    Use setup.cfg to configure your project.

    This file was generated with PyScaffold 3.2.3.
    PyScaffold helps you to put up the scaffold of your new Python project.
    Learn more under: https://pyscaffold.org/
"""
from pkg_resources import VersionConflict, require
from setuptools import setup

import sys

try:
    require("setuptools>=38.3")
except VersionConflict:
    print("Error: version of setuptools is too old (<38.3)!")
    sys.exit(1)


if __name__ == "__main__":
    setup(use_pyscaffold=True)
